/*
* Licensed to the Apache Software Foundation (ASF) under one or more
* contributor license agreements.  The ASF licenses this file to You
* under the Apache License, Version 2.0 (the "License"); you may not
* use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.  For additional information regarding
* copyright in this work, please see the NOTICE file in the top level
* directory of this distribution.
*/
package org.apache.abdera.i18n.templates;

import static java.lang.annotation.ElementType.TYPE;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

import java.lang.annotation.Retention;
import java.lang.annotation.Target;

/**
 * The URITemplate annotation can be used to associate a URI Template with a
 * particular Java class.  Instances of that class can then be expanded using
 * the associated URI Template.  The public fields and getter methods on the 
 * class will be automatically mapped to URI Template variable names. Alternative
 * varnames can be specified for each field/getter using the VarName annotation
 */
@Retention(RUNTIME)
@Target(TYPE)
public @interface URITemplate {
  String value();
  boolean isiri() default false;
}
